@@ -71,7 +71,7 @@ class AxonTracking:
         self._vscale = 1.5 * np.max(self.amplitudes)
 
     def select_channels(self, init_delay=None, detect_threshold=None,
-                        kurt_threshold=None, remove_isolated=None, neighbor_distance=50):
+                        kurt_threshold=None, remove_isolated=None, neighbor_distance=None):
         """
         Selects channels based on: detection threshold, kurtosis, peak time std, initial delay.
         Optionally removes isolated channels.
@@ -86,6 +86,8 @@ class AxonTracking:
         if remove_isolated is not None:
             assert isinstance(remove_isolated, bool), "'remove_isolated' must be a boolean"
             self._remove_isolated = remove_isolated
+        if neighbor_distance is None:
+            neighbor_distance = self._neighbor_radius
 
         if self._verbose > 0:
             print("Channel selection\n")
@@ -746,6 +748,8 @@ class GraphAxonTracking(AxonTracking):
                                 if i_s == 0:
                                     # re append branch point
                                     subpath = np.array([path[-1]] + list(subpath))
+                                else:
+                                    subpath = np.array(subpath)
 
                                 if self._is_path_valid(subpath):
                                     branch_dict = {}
@@ -795,6 +799,18 @@ class GraphAxonTracking(AxonTracking):
                             print(f"Removed path {p_i} for minimum path length: {self.compute_path_length(path)}um")
                         elif len(path) < self._min_path_points:
                             print(f"Removed path {p_i} for minimum path points: {len(path)} points")
+                    # remove branching points
+                    for bp in self._branching_points:
+                        if bp in path:
+                            # compute degree
+                            bp_degree = 0
+                            for p in self._paths_raw:
+                                if bp in p:
+                                    bp_degree += 1
+                            if bp_degree == 2:
+                                self._branching_points.remove(bp)
+                                if self._verbose > 0:
+                                    print(f"Removing branching point {bp}")
         else:
             if self._verbose > 0:
                 print(f"No points remaining for paht {p_i}")
@@ -966,7 +982,7 @@ class GraphAxonTracking(AxonTracking):
         return ax_raw
 
     def plot_clean_branches(self, plot_full_template=False, ax=None, cmap="rainbow",
-                            plot_bp=False):
+                            plot_bp=False, branch_colors=None):
         """Plots clean branches"""
         if ax is None:
             fig, ax_clean = plt.subplots()
@@ -974,10 +990,16 @@ class GraphAxonTracking(AxonTracking):
             ax_clean = ax
         cm = plt.get_cmap(cmap)
 
-        branch_colors = []
-        for i, path in enumerate(self._paths_raw):
-            color = cm(i / len(self._paths_raw))
-            branch_colors.append(color)
+        if branch_colors is None:
+            colors = []
+            for i, path in enumerate(self._paths_raw):
+                color = cm(i / len(self._paths_raw))
+                colors.append(color)
+            branch_colors = []
+            for i, branch in enumerate(self.branches):
+                branch_colors.append(colors[branch['raw_path_idx']])
+        else:
+            assert len(branch_colors) >= len(self.branches), "'branch_colors' is too short!"
         if plot_full_template:
             ax_clean.plot(self.locations[:, 0], self.locations[:, 1], marker=".", color="grey", ls="",
                           alpha=0.1)
@@ -986,16 +1008,17 @@ class GraphAxonTracking(AxonTracking):
                       self.locations[self.selected_channels, 1], marker=".", color="k", ls="", alpha=0.2)
 
         for i, branch in enumerate(self.branches):
-                path = branch['channels']
-                color = branch_colors[branch['raw_path_idx']]
-                ax_clean.plot(self.locations[path, 0], self.locations[path, 1], marker='o', ls='-',
-                              color=color, markeredgecolor="k", label=f"Clean branch {i}")
+            path = branch['channels']
+            color = branch_colors[i]
+            ax_clean.plot(self.locations[path, 0], self.locations[path, 1], marker='o', ls='-',
+                          color=color, markeredgecolor="k", label=f"Clean branch {i}")
         if plot_bp:
             for bp in self._branching_points:
                 ax_clean.plot(*self.locations[bp], marker='o', color="y", zorder=2, markersize=10, ls="")
         return ax_clean
 
-    def plot_velocities(self, fig=None, plot_outliers=False, cmap='rainbow'):
+    def plot_velocities(self, fig=None, plot_outliers=False, cmap='rainbow', markersize=10, alpha=0.3,
+                        alpha_outliers=0.7, fs=15, lw=2, markersize_out=10):
         """Plots branch velocities"""
         if fig is None:
             fig = plt.figure()
@@ -1017,13 +1040,14 @@ class GraphAxonTracking(AxonTracking):
                 peaks, dists = self._estimate_peaks_and_dists(path)
                 path_clean, velocity, offset, r2, p_value, dists_clean, peaks_clean, inlier_mask \
                     = self.robust_velocity_estimator(path, peaks, dists, True)
-                ax_vel.plot(peaks_clean, dists_clean, marker='o', ls='', color=color, alpha=0.3)
+                # ax_vel.plot(peaks_clean, dists_clean, marker='o', ls='', color=color, alpha=alpha)
                 outlier_idxs = np.where(inlier_mask == False)
                 plot_velocity(peaks[inlier_mask], dists[inlier_mask],
                               velocity, offset, color=color, r2=r2,
-                              ax=ax_vel, markeredgecolor="k", alpha_markers=0.5, lw=2)
-                ax_vel.plot(peaks[outlier_idxs], dists[outlier_idxs], marker='d', ls='', color=color, alpha=1,
-                            markersize=10, markeredgecolor="k", zorder=10)
+                              ax=ax_vel, markeredgecolor="k", alpha_markers=alpha, lw=2, markersize=markersize,
+                              fs=fs, plot_markers=True)
+                ax_vel.plot(peaks[outlier_idxs], dists[outlier_idxs], marker='d', ls='', color=color,
+                            markersize=markersize_out, markeredgecolor="k", zorder=10, alpha=alpha_outliers)
         else:
             for i, branch in enumerate(self.branches):
                 color = branch_colors[branch['raw_path_idx']]
@@ -1069,8 +1093,8 @@ class GraphAxonTracking(AxonTracking):
 
         for node_searched in self._nodes_searched:
             ax_nodes.scatter([self.locations[node_searched, 0]], [self.locations[node_searched, 1]],
-                             marker='o', s=15, zorder=10,
-                             facecolor=None, edgecolor='r')
+                             marker='D', s=30, zorder=10,
+                             facecolor="y", edgecolor='k')
             if node_searched_labels:
                 ax_nodes.text(self.locations[node_searched, 0], self.locations[node_searched, 1], str(node_searched),
                               color='r')
